.. _extending_outputs:

################################
Amending FitBenchmarking Outputs
################################

Here we describe how to add ways of displaying results obtained by FitBenchmarking.

.. toctree::
    :titlesonly:
    :maxdepth: 2
    :caption: Contents:

    tables
    templates
